@@ -44,223 +44,372 @@ class Ism8(asyncio.Protocol):
     # index of R/W-flag (writing not implemented so far)
     DP_UNIT = 4
     # index of unit description, if applicable
+    DP_VALUE_AREA = 5
+    # index of datapoint value area according to ism8 api, if applicable
 
     DATAPOINTS = {
-        1: ("HG1", "Stoerung", "DPT_Switch", False, ""),
-        2: ("HG1", "Betriebsart", "DPT_HVACContrMode", False, ""),
-        3: ("HG1", "Brennerleistung", "DPT_Scaling", False, "%"),
-        4: ("HG1", "Kesseltemperatur", "DPT_Value_Temp", False, "C"),
-        5: ("HG1", "Sammlertemperatur", "DPT_Value_Temp", False, "C"),
-        6: ("HG1", "Ruecklauftemperatur", "DPT_Value_Temp", False, "C"),
-        7: ("HG1", "Warmwassertemperatur", "DPT_Value_Temp", False, "C"),
-        8: ("HG1", "Aussentemperatur", "DPT_Value_Temp", False, "C"),
-        9: ("HG1", "Status Brenner", "DPT_Switch", False, ""),
-        10: ("HG1", "Status Heizkreispumpe", "DPT_Switch", False, ""),
-        11: ("HG1", "Status Speicherladepumpe", "DPT_Switch", False, ""),
-        12: ("HG1", "Status 3W-Umschaltventil", "DPT_OpenClose", False, ""),
-        13: ("HG1", "Anlagendruck", "DPT_Value_Pres", False, "Pa"),
-        14: ("HG2", "Stoerung", "DPT_Switch", False, ""),
-        15: ("HG2", "Betriebsart", "DPT_HVACContrMode", False, ""),
-        16: ("HG2", "Brennerleistung", "DPT_Scaling", False, "%"),
-        17: ("HG2", "Kesseltemperatur", "DPT_Value_Temp", False, "C"),
-        18: ("HG2", "Sammlertemperatur", "DPT_Value_Temp", False, "C"),
-        19: ("HG2", "Ruecklauftemperatur", "DPT_Value_Temp", False, "C"),
-        20: ("HG2", "Warmwassertemperatur", "DPT_Value_Temp", False, "C"),
-        21: ("HG2", "Aussentemperatur", "DPT_Value_Temp", False, "C"),
-        22: ("HG2", "Status Brenner", "DPT_Switch", False, ""),
-        23: ("HG2", "Status Heizkreispumpe", "DPT_Switch", False, ""),
-        24: ("HG2", "Status Speicherladepumpe", "DPT_Switch", False, ""),
-        25: ("HG2", "Status 3W-Umschaltventil", "DPT_OpenClose", False, ""),
-        26: ("HG2", "Anlagendruck", "DPT_Value_Pres", False, "Pa"),
-        27: ("HG3", "Stoerung", "DPT_Switch", False, ""),
-        28: ("HG3", "Betriebsart", "DPT_HVACContrMode", False, ""),
-        29: ("HG3", "Brennerleistung", "DPT_Scaling", False, "%"),
-        30: ("HG3", "Kesseltemperatur", "DPT_Value_Temp", False, "C"),
-        31: ("HG3", "Sammlertemperatur", "DPT_Value_Temp", False, "C"),
-        32: ("HG3", "Ruecklauftemperatur", "DPT_Value_Temp", False, "C"),
-        33: ("HG3", "Warmwassertemperatur", "DPT_Value_Temp", False, "C"),
-        34: ("HG3", "Aussentemperatur", "DPT_Value_Temp", False, "C"),
-        35: ("HG3", "Status Brenner", "DPT_Switch", False, ""),
-        36: ("HG3", "Status Heizkreispumpe", "DPT_Switch", False, ""),
-        37: ("HG3", "Status Speicherladepumpe", "DPT_Switch", False, ""),
-        38: ("HG3", "Status 3W-Umschaltventil", "DPT_OpenClose", False, ""),
-        39: ("HG3", "Anlagendruck", "DPT_Value_Pres", False, "Pa"),
-        40: ("HG4", "Stoerung", "DPT_Switch", False, ""),
-        41: ("HG4", "Betriebsart", "DPT_HVACContrMode", False, ""),
-        42: ("HG4", "Brennerleistung", "DPT_Scaling", False, "%"),
-        43: ("HG4", "Kesseltemperatur", "DPT_Value_Temp", False, "C"),
-        44: ("HG4", "Sammlertemperatur", "DPT_Value_Temp", False, "C"),
-        45: ("HG4", "Ruecklauftemperatur", "DPT_Value_Temp", False, "C"),
-        46: ("HG4", "Warmwassertemperatur", "DPT_Value_Temp", False, "C"),
-        47: ("HG4", "Aussentemperatur", "DPT_Value_Temp", False, "C"),
-        48: ("HG4", "Status Brenner", "DPT_Switch", False, ""),
-        49: ("HG4", "Status Heizkreispumpe", "DPT_Switch", False, ""),
-        50: ("HG4", "Status Speicherladepumpe", "DPT_Switch", False, ""),
-        51: ("HG4", "Status 3W-Umschaltventil", "DPT_OpenClose", False, ""),
-        52: ("HG4", "Anlagendruck", "DPT_Value_Pres", False, "a"),
-        53: ("BM1", "Stoerung", "DPT_Switch", False, ""),
-        54: ("BM1", "Aussentemperatur", "DPT_Value_Temp", False, "C"),
-        55: ("BM1", "Raumtemperatur", "DPT_Value_Temp", False, "C"),
-        56: ("BM1", "Warmwassersolltemperatur", "DPT_Value_Temp", True, "C"),
-        57: ("BM1", "Programmwahl Heizkreis", "DPT_HVACMode", True, ""),
-        58: ("BM1", "Programmwahl Warmwasser", "DPT_DHWMode", True, ""),
-        59: ("BM1", "Heizkreis Zeitprogramm 1", "DPT_Switch", True, ""),
-        60: ("BM1", "Heizkreis Zeitprogramm 2", "DPT_Switch", True, ""),
-        61: ("BM1", "Heizkreis Zeitprogramm 3", "DPT_Switch", True, ""),
-        62: ("BM1", "Warmwasser Zeitprogramm 1", "DPT_Switch", True, ""),
-        63: ("BM1", "Warmwasser Zeitprogramm 2", "DPT_Switch", True, ""),
-        64: ("BM1", "Warmwasser Zeitprogramm 3", "DPT_Switch", True, ""),
-        65: ("BM1", "Sollwertkorrektur", "DPT_Tempd", True, "K"),
-        66: ("BM1", "Sparfaktor", "DPT_Tempd", True, "K"),
-        67: ("BM2", "Stoerung", "DPT_Switch", False, ""),
-        68: ("BM2", "Raumtemperatur", "DPT_Value_Temp", False, "C"),
-        69: ("BM2", "Warmwassersolltemperatur", "DPT_Value_Temp", True, "C"),
-        70: ("BM2", "Programmwahl Mischer", "DPT_HVACMode", True, ""),
-        71: ("BM2", "Programmwahl Warmwasser", "DPT_DHWMode", True, ""),
-        72: ("BM2", "Mischer Zeitprogramm 1", "DPT_Switch", True, ""),
-        73: ("BM2", "Mischer Zeitprogramm 2", "DPT_Switch", True, ""),
-        74: ("BM2", "Mischer Zeitprogramm 3", "DPT_Switch", True, ""),
-        75: ("BM2", "Warmwasser Zeitprogramm 1", "DPT_Switch", True, ""),
-        76: ("BM2", "Warmwasser Zeitprogramm 2", "DPT_Switch", True, ""),
-        77: ("BM2", "Warmwasser Zeitprogramm 3", "DPT_Switch", True, ""),
-        78: ("BM2", "Sollwertkorrektur", "DPT_Tempd", True, "K"),
-        79: ("BM2", "Sparfaktor", "DPT_Tempd", True, "K"),
-        80: ("BM3", "Stoerung", "DPT_Switch", False, ""),
-        81: ("BM3", "Raumtemperatur", "DPT_Value_Temp", False, "C"),
-        82: ("BM3", "Warmwassersolltemperatur", "DPT_Value_Temp", True, "C"),
-        83: ("BM3", "Programmwahl Mischer", "DPT_HVACMode", True, ""),
-        84: ("BM3", "Programmwahl Warmwasser", "DPT_DHWMode", True, ""),
-        85: ("BM3", "Mischer Zeitprogramm 1", "DPT_Switch", True, ""),
-        86: ("BM3", "Mischer Zeitprogramm 2", "DPT_Switch", True, ""),
-        87: ("BM3", "Mischer Zeitprogramm 3", "DPT_Switch", True, ""),
-        88: ("BM3", "Warmwasser Zeitprogramm 1", "DPT_Switch", True, ""),
-        89: ("BM3", "Warmwasser Zeitprogramm 2", "DPT_Switch", True, ""),
-        90: ("BM3", "Warmwasser Zeitprogramm 3", "DPT_Switch", True, ""),
-        91: ("BM3", "Sollwertkorrektur", "DPT_Tempd", True, "K"),
-        92: ("BM3", "Sparfaktor", "DPT_Tempd", True, "K"),
-        93: ("BM4", "Stoerung", "DPT_Switch", False, ""),
-        94: ("BM4", "Raumtemperatur", "DPT_Value_Temp", False, "C"),
-        95: ("BM4", "Warmwassersolltemperatur", "DPT_Value_Temp", True, "C"),
-        96: ("BM4", "Programmwahl Mischer", "DPT_HVACMode", True, ""),
-        97: ("BM4", "Programmwahl Warmwasser", "DPT_DHWMode", True, ""),
-        98: ("BM4", "Mischer Zeitprogramm 1", "DPT_Switch", True, ""),
-        99: ("BM4", "Mischer Zeitprogramm 2", "DPT_Switch", True, ""),
-        100: ("BM4", "Mischer Zeitprogramm 3", "DPT_Switch", True, ""),
-        101: ("BM4", "Warmwasser Zeitprogramm 1", "DPT_Switch", True, ""),
-        102: ("BM4", "Warmwasser Zeitprogramm 2", "DPT_Switch", True, ""),
-        103: ("BM4", "Warmwasser Zeitprogramm 3", "DPT_Switch", True, ""),
-        104: ("BM4", "Sollwertkorrektur", "DPT_Tempd", True, "K"),
-        105: ("BM4", "Sparfaktor", "DPT_Tempd", True, "K"),
-        106: ("KM", "Stoerung", "DPT_Switch", False, ""),
-        107: ("KM", "Sammlertemperatur", "DPT_Value_Temp", False, "C"),
-        108: ("KM", "Gesamtmodulationsgrad", "DPT_Scaling", False, "%"),
-        109: ("KM", "Vorlauftemperatur Mischer", "DPT_Value_Temp", False, "C"),
-        110: ("KM", "Status Mischerkreispumpe", "DPT_Switch", False, ""),
-        111: ("KM", "Status Ausgang A1", "DPT_Enable", False, ""),
-        112: ("KM", "Eingang E1", "DPT_Value_Temp", False, "C"),
-        113: ("KM", "Eingang E2", "DPT_Value_Temp", False, "C"),
-        114: ("MM1", "Stoerung", "DPT_Switch", False, ""),
-        115: ("MM1", "Warmwassertemperatur", "DPT_Value_Temp", False, "C"),
-        116: ("MM1", "Vorlauftemperatur Mischer", "DPT_Value_Temp", False, "C"),
-        117: ("MM1", "Status Mischerkreispumpe", "DPT_Switch", False, ""),
-        118: ("MM1", "Status Ausgang A1", "DPT_Enable", False, ""),
-        119: ("MM1", "Eingang E1", "DPT_Value_Temp", False, "C"),
-        120: ("MM1", "Eingang E2", "DPT_Value_Temp", False, "C"),
-        121: ("MM2", "Stoerung", "DPT_Switch", False, ""),
-        122: ("MM2", "Warmwassertemperatur", "DPT_Value_Temp", False, "C"),
-        123: ("MM2", "Vorlauftemperatur Mischer", "DPT_Value_Temp", False, "C"),
-        124: ("MM2", "Status Mischerkreispumpe", "DPT_Switch", False, ""),
-        125: ("MM2", "Status Ausgang A1", "DPT_Enable", False, ""),
-        126: ("MM2", "Eingang E1", "DPT_Value_Temp", False, "C"),
-        127: ("MM2", "Eingang E2", "DPT_Value_Temp", False, "C"),
-        128: ("MM3", "Stoerung", "DPT_Switch", False, ""),
-        129: ("MM3", "Warmwassertemperatur", "DPT_Value_Temp", False, "C"),
-        130: ("MM3", "Vorlauftemperatur Mischer", "DPT_Value_Temp", False, "C"),
-        131: ("MM3", "Status Mischerkreispumpe", "DPT_Switch", False, ""),
-        132: ("MM3", "Status Ausgang A1", "DPT_Enable", False, ""),
-        133: ("MM3", "Eingang E1", "DPT_Value_Temp", False, "C"),
-        134: ("MM3", "Eingang E2", "DPT_Value_Temp", False, "C"),
-        135: ("SM", "Stoerung", "DPT_Switch", False, ""),
-        136: ("SM", "Warmwassertemperatur Solar 1", "DPT_Value_Temp", False, "C"),
-        137: ("SM", "Temperatur Kollektor 1", "DPT_Value_Temp", False, "C"),
-        138: ("SM", "Eingang E1", "DPT_Value_Temp", False, "C"),
-        139: ("SM", "Eingang E2 (Durchfluss)", "DPT_Value_Volume_Flow", False, "l/h"),
-        140: ("SM", "Eingang E3", "DPT_Value_Temp", False, "C"),
-        141: ("SM", "Status Solarkreispumpe SKP1", "DPT_Switch", False, ""),
-        142: ("SM", "Status Ausgang A1", "DPT_Enable", False, ""),
-        143: ("SM", "Status Ausgang A2", "DPT_Enable", False, ""),
-        144: ("SM", "Status Ausgang A3", "DPT_Enable", False, ""),
-        145: ("SM", "Status Ausgang A4", "DPT_Enable", False, ""),
-        146: ("SM", "Durchfluss", "DPT_Value_Volume_Flow", False, "l/h"),
-        147: ("SM", "aktuelle Leistung", "DPT_Power", False, "kW"),
-        148: ("CWL", "Stoerung", "DPT_Switch", False, ""),
-        149: ("CWL", "Programm", "DPT_DHWMode", True, ""),
-        150: ("CWL", "Zeitprogramm 1", "DPT_Switch", True, ""),
-        151: ("CWL", "Zeitprogramm 2", "DPT_Switch", True, ""),
-        152: ("CWL", "Zeitprogramm 3", "DPT_Switch", True, ""),
-        153: ("CWL", "Intensivlueftung AN_AUS", "DPT_Switch", True, ""),
-        154: ("CWL", "Intensivlueftung Startdatum", "DPT_Date", True, ""),
-        155: ("CWL", "Intensivlueftung Enddatum", "DPT_Date", True, ""),
-        156: ("CWL", "Intensivlueftung Startzeit", "DPT_TimeOfDay", True, ""),
-        157: ("CWL", "Intensivlueftung Endzeit", "DPT_TimeOfDay", True, ""),
-        158: ("CWL", "Zeitw. Feuchteschutz AN_AUS", "DPT_Switch", True, ""),
-        159: ("CWL", "Zeitw. Feuchteschutz Startdatum", "DPT_Date", True, ""),
-        160: ("CWL", "Zeitw. Feuchteschutz Enddatum", "DPT_Date", True, ""),
-        161: ("CWL", "Zeitw. Feuchteschutz Startzeit", "DPT_TimeOfDay", True, ""),
-        162: ("CWL", "Zeitw. Feuchteschutz Endzeit", "DPT_TimeOfDay", True, ""),
-        163: ("CWL", "Lueftungsstufe", "DPT_Scaling", False, "%"),
-        164: ("CWL", "Ablufttemperatur", "DPT_Value_Temp", False, "C"),
-        165: ("CWL", "Frischlufttemperatur", "DPT_Value_Temp", False, "C"),
-        166: ("CWL", "Durchsatz Zuluft", "DPT_FlowRate_m3/h", False, "m3/h"),
-        167: ("CWL", "Durchsatz Abluft", "DPT_FlowRate_m3/h", False, "m3/h"),
-        168: ("CWL", "Bypass Initialisierung", "DPT_Bool", False, ""),
-        169: ("CWL", "Bypass oeffnet_offen", "DPT_Bool", False, ""),
-        170: ("CWL", "Bypass schliesst_geschlossen", "DPT_Bool", False, ""),
-        171: ("CWL", "Bypass Fehler", "DPT_Bool", False, ""),
-        172: ("CWL", "Frost Status: Init_Warte", "DPT_Bool", False, ""),
-        173: ("CWL", "Frost Status: Kein Frost", "DPT_Bool", False, ""),
-        174: ("CWL", "Frost Status: Vorwaermer", "DPT_Bool", False, ""),
-        175: ("CWL", "Frost Status: Fehler", "DPT_Bool", False, ""),
-        176: ("BWL", "Stoerung", "DPT_Switch", False, ""),
-        177: ("BWL", "Betriebsart", "DPT_HVACContrMode", False, ""),
-        178: ("BWL", "Heizleistung", "DPT_Power", False, "W"),
-        179: ("BWL", "Kuehlleistung", "DPT_Power", False, "W"),
-        180: ("BWL", "Kesseltemperatur", "DPT_Value_Temp", False, "C"),
-        181: ("BWL", "Sammlertemperatur", "DPT_Value_Temp", False, "C"),
-        182: ("BWL", "Ruecklauftemperatur", "DPT_Value_Temp", False, "C"),
-        183: ("BWL", "Warmwassertemperatur", "DPT_Value_Temp", False, "C"),
-        184: ("BWL", "Aussentemperatur", "DPT_Value_Temp", False, "C"),
-        185: ("BWL", "Status Heizkreispumpe", "DPT_Switch", False, ""),
-        186: ("BWL", "Status Aux-Pumpe", "DPT_Switch", False, ""),
-        187: ("BWL", "3W-Umschaltventil HZ_WW", "DPT_OpenClose", False, ""),
-        188: ("BWL", "3W-Umschaltventil HZ_K", "DPT_OpenClose", False, ""),
-        189: ("BWL", "Status E-Heizung", "DPT_Switch", False, ""),
-        190: ("BWL", "Anlagendruck", "DPT_Value_Pres", False, "Pa"),
-        191: ("BWL", "Leistungsaufnahme", "DPT_Power", False, "W"),
-        192: ("CWL", "Filterwarnung aktiv", "DPT_Switch", False, "-"),
-        193: ("CWL", "Filterwarnung zuruecksetzen", "DPT_Switch", True, "-"),
-        194: ("BM1", "1x Warmwasserladung (gobal)", "DPT_Switch", True, "-"),
-        195: ("SM", "Tagesertrag", "DPT_ActiveEnergy", False, "Wh"),
-        196: ("SM", "Gesamtertrag", "DPT_ActiveEnergy_kWh", False, "kWh"),
-        197: ("HG1", "Abgastemperatur", "DPT_Value_Temp", False, "C"),
-        198: ("HG1", "Leistungsvorgabe", "DPT_Scaling", True, "%"),
-        199: ("HG1", "Kesseltemperaturvorgabe", "DPT_Value_Temp", True, "C"),
-        200: ("HG2", "Abgastemperatur", "DPT_Value_Temp", False, "C"),
-        201: ("HG2", "Leistungsvorgabe", "DPT_Scaling", True, "%"),
-        202: ("HG2", "Kesseltemperaturvorgabe", "DPT_Value_Temp", True, "C"),
-        203: ("HG3", "Abgastemperatur", "DPT_Value_Temp", False, "C"),
-        204: ("HG3", "Leistungsvorgabe", "DPT_Scaling", True, "%"),
-        205: ("HG3", "Kesseltemperaturvorgabe", "DPT_Value_Temp", True, "C"),
-        206: ("HG4", "Abgastemperatur", "DPT_Value_Temp", False, "C"),
-        207: ("HG4", "Leistungsvorgabe", "DPT_Scaling", True, "%"),
-        208: ("HG4", "Kesseltemperaturvorgabe", "DPT_Value_Temp", True, "C"),
-        209: ("KM", "Gesamtmodulationsgradvorgabe", "DPT_Scaling", True, "%"),
-        210: ("KM", "Sammlertemperaturvorgabe", "DPT_Value_Temp", True, "C"),
-        354: ("CWL", "undokumentiert_354", "DPT_unknown", False, ""),
-        355: ("CWL", "undokumentiert_355", "DPT_unknown", False, ""),
-        356: ("CWL", "undokumentiert_356", "DPT_unknown", False, ""),
-        357: ("CWL", "undokumentiert_357", "DPT_unknown", False, ""),
-        358: ("CWL", "undokumentiert_358", "DPT_unknown", False, ""),
+        1: ("HG1", "Stoerung", "DPT_Switch", False, "", None),
+        2: ("HG1", "Betriebsart", "DPT_HVACContrMode", False, "", None),
+        3: ("HG1", "Brennerleistung", "DPT_Scaling", False, "%", None),
+        4: ("HG1", "Kesseltemperatur", "DPT_Value_Temp", False, "C", None),
+        5: ("HG1", "Sammlertemperatur", "DPT_Value_Temp", False, "C", None),
+        6: ("HG1", "Ruecklauftemperatur", "DPT_Value_Temp", False, "C", None),
+        7: ("HG1", "Warmwassertemperatur", "DPT_Value_Temp", False, "C", None),
+        8: ("HG1", "Aussentemperatur", "DPT_Value_Temp", False, "C", None),
+        9: ("HG1", "Status Brenner", "DPT_Switch", False, "", None),
+        10: ("HG1", "Status Heizkreispumpe", "DPT_Switch", False, "", None),
+        11: ("HG1", "Status Speicherladepumpe", "DPT_Switch", False, "", None),
+        12: ("HG1", "Status 3W-Umschaltventil", "DPT_OpenClose", False, "", None),
+        13: ("HG1", "Anlagendruck", "DPT_Value_Pres", False, "Pa", None),
+        14: ("HG2", "Stoerung", "DPT_Switch", False, "", None),
+        15: ("HG2", "Betriebsart", "DPT_HVACContrMode", False, "", None),
+        16: ("HG2", "Brennerleistung", "DPT_Scaling", False, "%", None),
+        17: ("HG2", "Kesseltemperatur", "DPT_Value_Temp", False, "C", None),
+        18: ("HG2", "Sammlertemperatur", "DPT_Value_Temp", False, "C", None),
+        19: ("HG2", "Ruecklauftemperatur", "DPT_Value_Temp", False, "C", None),
+        20: ("HG2", "Warmwassertemperatur", "DPT_Value_Temp", False, "C", None),
+        21: ("HG2", "Aussentemperatur", "DPT_Value_Temp", False, "C", None),
+        22: ("HG2", "Status Brenner", "DPT_Switch", False, "", None),
+        23: ("HG2", "Status Heizkreispumpe", "DPT_Switch", False, "", None),
+        24: ("HG2", "Status Speicherladepumpe", "DPT_Switch", False, "", None),
+        25: ("HG2", "Status 3W-Umschaltventil", "DPT_OpenClose", False, "", None),
+        26: ("HG2", "Anlagendruck", "DPT_Value_Pres", False, "Pa", None),
+        27: ("HG3", "Stoerung", "DPT_Switch", False, "", None),
+        28: ("HG3", "Betriebsart", "DPT_HVACContrMode", False, "", None),
+        29: ("HG3", "Brennerleistung", "DPT_Scaling", False, "%", None),
+        30: ("HG3", "Kesseltemperatur", "DPT_Value_Temp", False, "C", None),
+        31: ("HG3", "Sammlertemperatur", "DPT_Value_Temp", False, "C", None),
+        32: ("HG3", "Ruecklauftemperatur", "DPT_Value_Temp", False, "C", None),
+        33: ("HG3", "Warmwassertemperatur", "DPT_Value_Temp", False, "C", None),
+        34: ("HG3", "Aussentemperatur", "DPT_Value_Temp", False, "C", None),
+        35: ("HG3", "Status Brenner", "DPT_Switch", False, "", None),
+        36: ("HG3", "Status Heizkreispumpe", "DPT_Switch", False, "", None),
+        37: ("HG3", "Status Speicherladepumpe", "DPT_Switch", False, "", None),
+        38: ("HG3", "Status 3W-Umschaltventil", "DPT_OpenClose", False, "", None),
+        39: ("HG3", "Anlagendruck", "DPT_Value_Pres", False, "Pa", None),
+        40: ("HG4", "Stoerung", "DPT_Switch", False, "", None),
+        41: ("HG4", "Betriebsart", "DPT_HVACContrMode", False, "", None),
+        42: ("HG4", "Brennerleistung", "DPT_Scaling", False, "%", None),
+        43: ("HG4", "Kesseltemperatur", "DPT_Value_Temp", False, "C", None),
+        44: ("HG4", "Sammlertemperatur", "DPT_Value_Temp", False, "C", None),
+        45: ("HG4", "Ruecklauftemperatur", "DPT_Value_Temp", False, "C", None),
+        46: ("HG4", "Warmwassertemperatur", "DPT_Value_Temp", False, "C", None),
+        47: ("HG4", "Aussentemperatur", "DPT_Value_Temp", False, "C", None),
+        48: ("HG4", "Status Brenner", "DPT_Switch", False, "", None),
+        49: ("HG4", "Status Heizkreispumpe", "DPT_Switch", False, "", None),
+        50: ("HG4", "Status Speicherladepumpe", "DPT_Switch", False, "", None),
+        51: ("HG4", "Status 3W-Umschaltventil", "DPT_OpenClose", False, "", None),
+        52: ("HG4", "Anlagendruck", "DPT_Value_Pres", False, "a", None),
+        53: ("BM1", "Stoerung", "DPT_Switch", False, "", None),
+        54: ("BM1", "Aussentemperatur", "DPT_Value_Temp", False, "C", None),
+        55: ("BM1", "Raumtemperatur", "DPT_Value_Temp", False, "C", None),
+        56: (
+            "BM1",
+            "Warmwassersolltemperatur",
+            "DPT_Value_Temp",
+            True,
+            "C",
+            [i for i in range(20, 81, 1)],
+        ),
+        57: (
+            "BM1",
+            "Programmwahl Heizkreis",
+            "DPT_HVACMode",
+            True,
+            "",
+            [i for i in range(0, 4, 1)],
+        ),
+        58: (
+            "BM1",
+            "Programmwahl Warmwasser",
+            "DPT_DHWMode",
+            True,
+            "",
+            [i for i in range(0, 5, 2)],
+        ),
+        59: ("BM1", "Heizkreis Zeitprogramm 1", "DPT_Switch", True, "", [0, 1]),
+        60: ("BM1", "Heizkreis Zeitprogramm 2", "DPT_Switch", True, "", [0, 1]),
+        61: ("BM1", "Heizkreis Zeitprogramm 3", "DPT_Switch", True, "", [0, 1]),
+        62: ("BM1", "Warmwasser Zeitprogramm 1", "DPT_Switch", True, "", [0, 1]),
+        63: ("BM1", "Warmwasser Zeitprogramm 2", "DPT_Switch", True, "", [0, 1]),
+        64: ("BM1", "Warmwasser Zeitprogramm 3", "DPT_Switch", True, "", [0, 1]),
+        65: (
+            "BM1",
+            "Sollwertkorrektur",
+            "DPT_Tempd",
+            True,
+            "K",
+            [(i / 10) for i in range(-40, 45, 5)],
+        ),
+        66: (
+            "BM1",
+            "Sparfaktor",
+            "DPT_Tempd",
+            True,
+            "K",
+            [(i / 10) for i in range(0, 105, 5)],
+        ),
+        67: ("BM2", "Stoerung", "DPT_Switch", False, "", None),
+        68: ("BM2", "Raumtemperatur", "DPT_Value_Temp", False, "C", None),
+        69: (
+            "BM2",
+            "Warmwassersolltemperatur",
+            "DPT_Value_Temp",
+            True,
+            "C",
+            [i for i in range(20, 81, 1)],
+        ),
+        70: (
+            "BM2",
+            "Programmwahl Mischer",
+            "DPT_HVACMode",
+            True,
+            "",
+            [i for i in range(0, 4, 1)],
+        ),
+        71: (
+            "BM2",
+            "Programmwahl Warmwasser",
+            "DPT_DHWMode",
+            True,
+            "",
+            [i for i in range(0, 5, 2)],
+        ),
+        72: ("BM2", "Mischer Zeitprogramm 1", "DPT_Switch", True, "", [0, 1]),
+        73: ("BM2", "Mischer Zeitprogramm 2", "DPT_Switch", True, "", [0, 1]),
+        74: ("BM2", "Mischer Zeitprogramm 3", "DPT_Switch", True, "", [0, 1]),
+        75: ("BM2", "Warmwasser Zeitprogramm 1", "DPT_Switch", True, "", [0, 1]),
+        76: ("BM2", "Warmwasser Zeitprogramm 2", "DPT_Switch", True, "", [0, 1]),
+        77: ("BM2", "Warmwasser Zeitprogramm 3", "DPT_Switch", True, "", [0, 1]),
+        78: (
+            "BM2",
+            "Sollwertkorrektur",
+            "DPT_Tempd",
+            True,
+            "K",
+            [(i / 10) for i in range(-40, 45, 5)],
+        ),
+        79: (
+            "BM2",
+            "Sparfaktor",
+            "DPT_Tempd",
+            True,
+            "K",
+            [(i / 10) for i in range(0, 105, 5)],
+        ),
+        80: ("BM3", "Stoerung", "DPT_Switch", False, "", None),
+        81: ("BM3", "Raumtemperatur", "DPT_Value_Temp", False, "C", None),
+        82: (
+            "BM3",
+            "Warmwassersolltemperatur",
+            "DPT_Value_Temp",
+            True,
+            "C",
+            [i for i in range(20, 81, 1)],
+        ),
+        83: (
+            "BM3",
+            "Programmwahl Mischer",
+            "DPT_HVACMode",
+            True,
+            "",
+            [i for i in range(0, 4, 1)],
+        ),
+        84: (
+            "BM3",
+            "Programmwahl Warmwasser",
+            "DPT_DHWMode",
+            True,
+            "",
+            [i for i in range(0, 5, 2)],
+        ),
+        85: ("BM3", "Mischer Zeitprogramm 1", "DPT_Switch", True, "", [0, 1]),
+        86: ("BM3", "Mischer Zeitprogramm 2", "DPT_Switch", True, "", [0, 1]),
+        87: ("BM3", "Mischer Zeitprogramm 3", "DPT_Switch", True, "", [0, 1]),
+        88: ("BM3", "Warmwasser Zeitprogramm 1", "DPT_Switch", True, "", [0, 1]),
+        89: ("BM3", "Warmwasser Zeitprogramm 2", "DPT_Switch", True, "", [0, 1]),
+        90: ("BM3", "Warmwasser Zeitprogramm 3", "DPT_Switch", True, "", [0, 1]),
+        91: (
+            "BM3",
+            "Sollwertkorrektur",
+            "DPT_Tempd",
+            True,
+            "K",
+            [(i / 10) for i in range(-40, 45, 5)],
+        ),
+        92: (
+            "BM3",
+            "Sparfaktor",
+            "DPT_Tempd",
+            True,
+            "K",
+            [(i / 10) for i in range(0, 105, 5)],
+        ),
+        93: ("BM4", "Stoerung", "DPT_Switch", False, "", None),
+        94: ("BM4", "Raumtemperatur", "DPT_Value_Temp", False, "C", None),
+        95: (
+            "BM4",
+            "Warmwassersolltemperatur",
+            "DPT_Value_Temp",
+            True,
+            "C",
+            [i for i in range(20, 81, 1)],
+        ),
+        96: (
+            "BM4",
+            "Programmwahl Mischer",
+            "DPT_HVACMode",
+            True,
+            "",
+            [i for i in range(0, 4, 1)],
+        ),
+        97: (
+            "BM4",
+            "Programmwahl Warmwasser",
+            "DPT_DHWMode",
+            True,
+            "",
+            [i for i in range(0, 5, 2)],
+        ),
+        98: ("BM4", "Mischer Zeitprogramm 1", "DPT_Switch", True, "", [0, 1]),
+        99: ("BM4", "Mischer Zeitprogramm 2", "DPT_Switch", True, "", [0, 1]),
+        100: ("BM4", "Mischer Zeitprogramm 3", "DPT_Switch", True, "", [0, 1]),
+        101: ("BM4", "Warmwasser Zeitprogramm 1", "DPT_Switch", True, "", [0, 1]),
+        102: ("BM4", "Warmwasser Zeitprogramm 2", "DPT_Switch", True, "", [0, 1]),
+        103: ("BM4", "Warmwasser Zeitprogramm 3", "DPT_Switch", True, "", [0, 1]),
+        104: (
+            "BM4",
+            "Sollwertkorrektur",
+            "DPT_Tempd",
+            True,
+            "K",
+            [(i / 10) for i in range(-40, 45, 5)],
+        ),
+        105: (
+            "BM4",
+            "Sparfaktor",
+            "DPT_Tempd",
+            True,
+            "K",
+            [(i / 10) for i in range(0, 105, 5)],
+        ),
+        106: ("KM", "Stoerung", "DPT_Switch", False, "", None),
+        107: ("KM", "Sammlertemperatur", "DPT_Value_Temp", False, "C", None),
+        108: ("KM", "Gesamtmodulationsgrad", "DPT_Scaling", False, "%", None),
+        109: ("KM", "Vorlauftemperatur Mischer", "DPT_Value_Temp", False, "C", None),
+        110: ("KM", "Status Mischerkreispumpe", "DPT_Switch", False, "", None),
+        111: ("KM", "Status Ausgang A1", "DPT_Enable", False, "", None),
+        112: ("KM", "Eingang E1", "DPT_Value_Temp", False, "C", None),
+        113: ("KM", "Eingang E2", "DPT_Value_Temp", False, "C", None),
+        114: ("MM1", "Stoerung", "DPT_Switch", False, "", None),
+        115: ("MM1", "Warmwassertemperatur", "DPT_Value_Temp", False, "C", None),
+        116: ("MM1", "Vorlauftemperatur Mischer", "DPT_Value_Temp", False, "C", None),
+        117: ("MM1", "Status Mischerkreispumpe", "DPT_Switch", False, "", None),
+        118: ("MM1", "Status Ausgang A1", "DPT_Enable", False, "", None),
+        119: ("MM1", "Eingang E1", "DPT_Value_Temp", False, "C", None),
+        120: ("MM1", "Eingang E2", "DPT_Value_Temp", False, "C", None),
+        121: ("MM2", "Stoerung", "DPT_Switch", False, "", None),
+        122: ("MM2", "Warmwassertemperatur", "DPT_Value_Temp", False, "C", None),
+        123: ("MM2", "Vorlauftemperatur Mischer", "DPT_Value_Temp", False, "C", None),
+        124: ("MM2", "Status Mischerkreispumpe", "DPT_Switch", False, "", None),
+        125: ("MM2", "Status Ausgang A1", "DPT_Enable", False, "", None),
+        126: ("MM2", "Eingang E1", "DPT_Value_Temp", False, "C", None),
+        127: ("MM2", "Eingang E2", "DPT_Value_Temp", False, "C", None),
+        128: ("MM3", "Stoerung", "DPT_Switch", False, "", None),
+        129: ("MM3", "Warmwassertemperatur", "DPT_Value_Temp", False, "C", None),
+        130: ("MM3", "Vorlauftemperatur Mischer", "DPT_Value_Temp", False, "C", None),
+        131: ("MM3", "Status Mischerkreispumpe", "DPT_Switch", False, "", None),
+        132: ("MM3", "Status Ausgang A1", "DPT_Enable", False, "", None),
+        133: ("MM3", "Eingang E1", "DPT_Value_Temp", False, "C", None),
+        134: ("MM3", "Eingang E2", "DPT_Value_Temp", False, "C", None),
+        135: ("SM", "Stoerung", "DPT_Switch", False, "", None),
+        136: ("SM", "Warmwassertemperatur Solar 1", "DPT_Value_Temp", False, "C", None),
+        137: ("SM", "Temperatur Kollektor 1", "DPT_Value_Temp", False, "C", None),
+        138: ("SM", "Eingang E1", "DPT_Value_Temp", False, "C", None),
+        139: (
+            "SM",
+            "Eingang E2 (Durchfluss)",
+            "DPT_Value_Volume_Flow",
+            False,
+            "l/h",
+            None,
+        ),
+        140: ("SM", "Eingang E3", "DPT_Value_Temp", False, "C", None),
+        141: ("SM", "Status Solarkreispumpe SKP1", "DPT_Switch", False, "", None),
+        142: ("SM", "Status Ausgang A1", "DPT_Enable", False, "", None),
+        143: ("SM", "Status Ausgang A2", "DPT_Enable", False, "", None),
+        144: ("SM", "Status Ausgang A3", "DPT_Enable", False, "", None),
+        145: ("SM", "Status Ausgang A4", "DPT_Enable", False, "", None),
+        146: ("SM", "Durchfluss", "DPT_Value_Volume_Flow", False, "l/h", None),
+        147: ("SM", "aktuelle Leistung", "DPT_Power", False, "kW", None),
+        148: ("CWL", "Stoerung", "DPT_Switch", False, "", None),
+        149: ("CWL", "Programm", "DPT_DHWMode", True, "", [0, 1, 3]),
+        150: ("CWL", "Zeitprogramm 1", "DPT_Switch", True, "", [0, 1]),
+        151: ("CWL", "Zeitprogramm 2", "DPT_Switch", True, "", [0, 1]),
+        152: ("CWL", "Zeitprogramm 3", "DPT_Switch", True, "", [0, 1]),
+        153: ("CWL", "Intensivlueftung AN_AUS", "DPT_Switch", True, "", [0, 1]),
+        154: ("CWL", "Intensivlueftung Startdatum", "DPT_Date", True, "", None),
+        155: ("CWL", "Intensivlueftung Enddatum", "DPT_Date", True, "", None),
+        156: ("CWL", "Intensivlueftung Startzeit", "DPT_TimeOfDay", True, "", None),
+        157: ("CWL", "Intensivlueftung Endzeit", "DPT_TimeOfDay", True, "", None),
+        158: ("CWL", "Zeitw. Feuchteschutz AN_AUS", "DPT_Switch", True, "", [0, 1]),
+        159: ("CWL", "Zeitw. Feuchteschutz Startdatum", "DPT_Date", True, "", None),
+        160: ("CWL", "Zeitw. Feuchteschutz Enddatum", "DPT_Date", True, "", None),
+        161: ("CWL", "Zeitw. Feuchteschutz Startzeit", "DPT_TimeOfDay", True, "", None),
+        162: ("CWL", "Zeitw. Feuchteschutz Endzeit", "DPT_TimeOfDay", True, "", None),
+        163: ("CWL", "Lueftungsstufe", "DPT_Scaling", False, "%", None),
+        164: ("CWL", "Ablufttemperatur", "DPT_Value_Temp", False, "C", None),
+        165: ("CWL", "Frischlufttemperatur", "DPT_Value_Temp", False, "C", None),
+        166: ("CWL", "Durchsatz Zuluft", "DPT_FlowRate_m3/h", False, "m3/h", None),
+        167: ("CWL", "Durchsatz Abluft", "DPT_FlowRate_m3/h", False, "m3/h", None),
+        168: ("CWL", "Bypass Initialisierung", "DPT_Bool", False, "", None),
+        169: ("CWL", "Bypass oeffnet_offen", "DPT_Bool", False, "", None),
+        170: ("CWL", "Bypass schliesst_geschlossen", "DPT_Bool", False, "", None),
+        171: ("CWL", "Bypass Fehler", "DPT_Bool", False, "", None),
+        172: ("CWL", "Frost Status: Init_Warte", "DPT_Bool", False, "", None),
+        173: ("CWL", "Frost Status: Kein Frost", "DPT_Bool", False, "", None),
+        174: ("CWL", "Frost Status: Vorwaermer", "DPT_Bool", False, "", None),
+        175: ("CWL", "Frost Status: Fehler", "DPT_Bool", False, "", None),
+        176: ("BWL", "Stoerung", "DPT_Switch", False, "", None),
+        177: ("BWL", "Betriebsart", "DPT_HVACContrMode", False, "", None),
+        178: ("BWL", "Heizleistung", "DPT_Power", False, "W", None),
+        179: ("BWL", "Kuehlleistung", "DPT_Power", False, "W", None),
+        180: ("BWL", "Kesseltemperatur", "DPT_Value_Temp", False, "C", None),
+        181: ("BWL", "Sammlertemperatur", "DPT_Value_Temp", False, "C", None),
+        182: ("BWL", "Ruecklauftemperatur", "DPT_Value_Temp", False, "C", None),
+        183: ("BWL", "Warmwassertemperatur", "DPT_Value_Temp", False, "C", None),
+        184: ("BWL", "Aussentemperatur", "DPT_Value_Temp", False, "C", None),
+        185: ("BWL", "Status Heizkreispumpe", "DPT_Switch", False, "", None),
+        186: ("BWL", "Status Aux-Pumpe", "DPT_Switch", False, "", None),
+        187: ("BWL", "3W-Umschaltventil HZ_WW", "DPT_OpenClose", False, "", None),
+        188: ("BWL", "3W-Umschaltventil HZ_K", "DPT_OpenClose", False, "", None),
+        189: ("BWL", "Status E-Heizung", "DPT_Switch", False, "", None),
+        190: ("BWL", "Anlagendruck", "DPT_Value_Pres", False, "Pa", None),
+        191: ("BWL", "Leistungsaufnahme", "DPT_Power", False, "W", None),
+        192: ("CWL", "Filterwarnung aktiv", "DPT_Switch", False, "-", None),
+        193: ("CWL", "Filterwarnung zuruecksetzen", "DPT_Switch", True, "-", [0, 1]),
+        194: ("BM1", "1x Warmwasserladung (gobal)", "DPT_Switch", True, "-", [0, 1]),
+        195: ("SM", "Tagesertrag", "DPT_ActiveEnergy", False, "Wh", None),
+        196: ("SM", "Gesamtertrag", "DPT_ActiveEnergy_kWh", False, "kWh", None),
+        197: ("HG1", "Abgastemperatur", "DPT_Value_Temp", False, "C", None),
+        198: ("HG1", "Leistungsvorgabe", "DPT_Scaling", True, "%", None),
+        199: ("HG1", "Kesseltemperaturvorgabe", "DPT_Value_Temp", True, "C", None),
+        200: ("HG2", "Abgastemperatur", "DPT_Value_Temp", False, "C", None),
+        201: ("HG2", "Leistungsvorgabe", "DPT_Scaling", True, "%", None),
+        202: ("HG2", "Kesseltemperaturvorgabe", "DPT_Value_Temp", True, "C", None),
+        203: ("HG3", "Abgastemperatur", "DPT_Value_Temp", False, "C", None),
+        204: ("HG3", "Leistungsvorgabe", "DPT_Scaling", True, "%", None),
+        205: ("HG3", "Kesseltemperaturvorgabe", "DPT_Value_Temp", True, "C", None),
+        206: ("HG4", "Abgastemperatur", "DPT_Value_Temp", False, "C", None),
+        207: ("HG4", "Leistungsvorgabe", "DPT_Scaling", True, "%", None),
+        208: ("HG4", "Kesseltemperaturvorgabe", "DPT_Value_Temp", True, "C", None),
+        209: ("KM", "Gesamtmodulationsgradvorgabe", "DPT_Scaling", True, "%", None),
+        210: ("KM", "Sammlertemperaturvorgabe", "DPT_Value_Temp", True, "C", None),
+        354: ("CWL", "undokumentiert_354", "DPT_unknown", False, "", None),
+        355: ("CWL", "undokumentiert_355", "DPT_unknown", False, "", None),
+        356: ("CWL", "undokumentiert_356", "DPT_unknown", False, "", None),
+        357: ("CWL", "undokumentiert_357", "DPT_unknown", False, "", None),
+        358: ("CWL", "undokumentiert_358", "DPT_unknown", False, "", None),
     }
 
     DT_MIN = 0
@@ -282,6 +431,7 @@ class Ism8(asyncio.Protocol):
         "DPT_Scaling": (0.00, 100.00, type(float), 100 / 255, "%"),
         "DPT_Value_Temp": (-273.00, 670760.00, type(float), 1 / 100, "C"),
         "DPT_Value_Tempd": (-670760.00, 670760.00, type(float), 1 / 100, "K"),
+        "DPT_Tempd": (-670760.00, 670760.00, type(float), 1 / 100, "K"),
         "DPT_Value_Pres": (0, 670760.00, type(float), 1 / 100, "Pa"),
         "DPT_Power": (-670760.00, 670760.00, type(float), 1 / 100, "kW"),
         "DPT_Value_Volume_Flow": (-670760.00, 670760.00, type(float), 1 / 100, "l/h"),
@@ -291,6 +441,7 @@ class Ism8(asyncio.Protocol):
         "DPT_HVACMode": (0, 4, type(int), 1, None),
         "DPT_DHWMode": (0, 4, type(int), 1, None),
         "DPT_HVACContrMode": (0, 20, type(int), 1, None),
+        "DPT_HVACContrMode": (0, 20, type(int), 1, None),
     }
 
     HVACModes = {
@@ -345,6 +496,11 @@ class Ism8(asyncio.Protocol):
         """returns sensor type from private array of sensor-readings"""
         return Ism8.DATAPOINTS.get(dp_id, ["", "", "", "", ""])[Ism8.DP_RW]
 
+    @staticmethod
+    def get_value_area(dp_id) -> Optional[list[Any]]:
+        """returns sensor type from private array of sensor-readings"""
+        return Ism8.DATAPOINTS.get(dp_id, ["", "", "", "", ""])[Ism8.DP_VALUE_AREA]
+
     @staticmethod
     def get_min_value(dp_id: int) -> Any:
         """returns min value allowed for datapoint"""
